Insertar tabla

Insertar tabla | TOC

El botón insertar tabla abre la siguiente ventana. Esta acci&ocaute;n te permite crear tablas.
Descripción de los campos:

Columns | Número de columnas.
Rows | NAúmero de filas.
Cellpadding | Desplazamiento entre celdas .
Cellspacing | Espacio entre celdas .
Alignment | Alineamiento de la tabla.
Border | Anchura del borde de la tabla.
Width | Anchura de la tabla en pixels .
Height | Altura de la tabla en pixels.

Ir a: Tabla de contenidos | Top